#!/work/ci_py311/gdal_1676844038449/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac/bin/python

import sys
# import osgeo_utils.gdal_calc as a convenience to use as a script
from osgeo_utils.gdal_calc import *  # noqa
from osgeo_utils.gdal_calc import main
from osgeo.gdal import deprecation_warn


deprecation_warn('gdal_calc')
sys.exit(main(sys.argv))
